Iteration
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   multiple_assignment.rst
   iteration.rst
   the_while_statement.rst
   tables.rst
   two_dimensional_tables.rst
   encapsulation_generalization.rst
   functions.rst
   more_encapsulation.rst
   local_variables.rst
   more_generalization.rst
   glossary.rst
   Exercises.rst
   mixed_up_code.rst
   coding_practice.rst